==> gorilla-notes-0.2.0-20200816.184600-3.jar: public/js/compiled/cljs-runtime/module$node_modules$react_draggable$build$cjs$utils$domFns.js <==
shadow$provide.module$node_modules$react_draggable$build$cjs$utils$domFns=function(global,require,module,exports){function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;
var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}
function matchesSelector(el,selector){matchesSelectorFunc||(matchesSelectorFunc=(0,_shims.findInArray)(["matches","webkitMatchesSelector","mozMatchesSelector","msMatchesSelector","oMatchesSelector"],function(method){return(0,_shims.isFunction)(el[method])}));return(0,_shims.isFunction)(el[matchesSelectorFunc])?el[matchesSelectorFunc](selector):!1}function getTranslation(_ref2,positionOffset,unitSuffix){var y=_ref2.y;_ref2="translate(".concat(_ref2.x).concat(unitSuffix,",").concat(y).concat(unitSuffix,
")");positionOffset&&(y="".concat("string"===typeof positionOffset.x?positionOffset.x:positionOffset.x+unitSuffix),positionOffset="".concat("string"===typeof positionOffset.y?positionOffset.y:positionOffset.y+unitSuffix),_ref2="translate(".concat(y,", ").concat(positionOffset,")")+_ref2);return _ref2}function addClassName(el,className){el.classList?el.classList.add(className):el.className.match(new RegExp("(?:^|\\s)".concat(className,"(?!\\S)")))||(el.className+=" ".concat(className))}function removeClassName(el,
className){el.classList?el.classList.remove(className):el.className=el.className.replace(new RegExp("(?:^|\\s)".concat(className,"(?!\\S)"),"g"),"")}Object.defineProperty(exports,"__esModule",{value:!0});exports.matchesSelector=matchesSelector;exports.matchesSelectorAndParentsTo=function(el,selector,baseNode){do{if(matchesSelector(el,selector))return!0;if(el===baseNode)break;el=el.parentNode}while(el);return!1};exports.addEvent=function(el,event,handler,inputOptions){el&&(inputOptions=_objectSpread({capture:!0},
inputOptions),el.addEventListener?el.addEventListener(event,handler,inputOptions):el.attachEvent?el.attachEvent("on"+event,handler):el["on"+event]=handler)};exports.removeEvent=function(el,event,handler,inputOptions){el&&(inputOptions=_objectSpread({capture:!0},inputOptions),el.removeEventListener?el.removeEventListener(event,handler,inputOptions):el.detachEvent?el.detachEvent("on"+event,handler):el["on"+event]=null)};exports.outerHeight=function(node){var height=node.clientHeight;node=node.ownerDocument.defaultView.getComputedStyle(node);
height+=(0,_shims.int)(node.borderTopWidth);return height+=(0,_shims.int)(node.borderBottomWidth)};exports.outerWidth=function(node){var width=node.clientWidth;node=node.ownerDocument.defaultView.getComputedStyle(node);width+=(0,_shims.int)(node.borderLeftWidth);return width+=(0,_shims.int)(node.borderRightWidth)};exports.innerHeight=function(node){var height=node.clientHeight;node=node.ownerDocument.defaultView.getComputedStyle(node);height-=(0,_shims.int)(node.paddingTop);return height-=(0,_shims.int)(node.paddingBottom)};
exports.innerWidth=function(node){var width=node.clientWidth;node=node.ownerDocument.defaultView.getComputedStyle(node);width-=(0,_shims.int)(node.paddingLeft);return width-=(0,_shims.int)(node.paddingRight)};exports.offsetXYFromParent=function(evt,offsetParent,scale){var offsetParentRect=offsetParent===offsetParent.ownerDocument.body?{left:0,top:0}:offsetParent.getBoundingClientRect();return{x:(evt.clientX+offsetParent.scrollLeft-offsetParentRect.left)/scale,y:(evt.clientY+offsetParent.scrollTop-
offsetParentRect.top)/scale}};exports.createCSSTransform=function(controlPos,positionOffset){controlPos=getTranslation(controlPos,positionOffset,"px");return _defineProperty({},(0,_getPrefix.browserPrefixToKey)("transform",_getPrefix.default),controlPos)};exports.createSVGTransform=function(controlPos,positionOffset){return getTranslation(controlPos,positionOffset,"")};exports.getTranslation=getTranslation;exports.getTouch=function(e,identifier){return e.targetTouches&&(0,_shims.findInArray)(e.targetTouches,
function(t){return identifier===t.identifier})||e.changedTouches&&(0,_shims.findInArray)(e.changedTouches,function(t){return identifier===t.identifier})};exports.getTouchIdentifier=function(e){if(e.targetTouches&&e.targetTouches[0])return e.targetTouches[0].identifier;if(e.changedTouches&&e.changedTouches[0])return e.changedTouches[0].identifier};exports.addUserSelectStyles=function(doc){if(doc){var styleEl=doc.getElementById("react-draggable-style-el");styleEl||(styleEl=doc.createElement("style"),
styleEl.type="text/css",styleEl.id="react-draggable-style-el",styleEl.innerHTML=".react-draggable-transparent-selection *::-moz-selection {all: inherit;}\n",styleEl.innerHTML+=".react-draggable-transparent-selection *::selection {all: inherit;}\n",doc.getElementsByTagName("head")[0].appendChild(styleEl));doc.body&&addClassName(doc.body,"react-draggable-transparent-selection")}};exports.removeUserSelectStyles=function(doc){if(doc)try{if(doc.body&&removeClassName(doc.body,"react-draggable-transparent-selection"),
doc.selection)doc.selection.empty();else{var selection=(doc.defaultView||window).getSelection();selection&&"Caret"!==selection.type&&selection.removeAllRanges()}}catch(e){}};exports.addClassName=addClassName;exports.removeClassName=removeClassName;var _shims=require("module$node_modules$react_draggable$build$cjs$utils$shims"),_getPrefix=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{default:obj};var cache=_getRequireWildcardCache();
if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj.default=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react_draggable$build$cjs$utils$getPrefix")),
matchesSelectorFunc=""}
//# sourceMappingURL=module$node_modules$react_draggable$build$cjs$utils$domFns.js.map

==> gorilla-notes-0.4.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_draggable$build$cjs$utils$domFns.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_draggable$build$cjs$utils$domFns=function(global,require,module,exports){function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;
var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}
function matchesSelector(el,selector){matchesSelectorFunc||(matchesSelectorFunc=(0,_shims.findInArray)(["matches","webkitMatchesSelector","mozMatchesSelector","msMatchesSelector","oMatchesSelector"],function(method){return(0,_shims.isFunction)(el[method])}));return(0,_shims.isFunction)(el[matchesSelectorFunc])?el[matchesSelectorFunc](selector):!1}function getTranslation(_ref2,positionOffset,unitSuffix){var y=_ref2.y;_ref2="translate(".concat(_ref2.x).concat(unitSuffix,",").concat(y).concat(unitSuffix,
")");positionOffset&&(y="".concat("string"===typeof positionOffset.x?positionOffset.x:positionOffset.x+unitSuffix),positionOffset="".concat("string"===typeof positionOffset.y?positionOffset.y:positionOffset.y+unitSuffix),_ref2="translate(".concat(y,", ").concat(positionOffset,")")+_ref2);return _ref2}function addClassName(el,className){el.classList?el.classList.add(className):el.className.match(new RegExp("(?:^|\\s)".concat(className,"(?!\\S)")))||(el.className+=" ".concat(className))}function removeClassName(el,
className){el.classList?el.classList.remove(className):el.className=el.className.replace(new RegExp("(?:^|\\s)".concat(className,"(?!\\S)"),"g"),"")}Object.defineProperty(exports,"__esModule",{value:!0});exports.matchesSelector=matchesSelector;exports.matchesSelectorAndParentsTo=function(el,selector,baseNode){do{if(matchesSelector(el,selector))return!0;if(el===baseNode)break;el=el.parentNode}while(el);return!1};exports.addEvent=function(el,event,handler,inputOptions){el&&(inputOptions=_objectSpread({capture:!0},
inputOptions),el.addEventListener?el.addEventListener(event,handler,inputOptions):el.attachEvent?el.attachEvent("on"+event,handler):el["on"+event]=handler)};exports.removeEvent=function(el,event,handler,inputOptions){el&&(inputOptions=_objectSpread({capture:!0},inputOptions),el.removeEventListener?el.removeEventListener(event,handler,inputOptions):el.detachEvent?el.detachEvent("on"+event,handler):el["on"+event]=null)};exports.outerHeight=function(node){var height=node.clientHeight;node=node.ownerDocument.defaultView.getComputedStyle(node);
height+=(0,_shims.int)(node.borderTopWidth);return height+=(0,_shims.int)(node.borderBottomWidth)};exports.outerWidth=function(node){var width=node.clientWidth;node=node.ownerDocument.defaultView.getComputedStyle(node);width+=(0,_shims.int)(node.borderLeftWidth);return width+=(0,_shims.int)(node.borderRightWidth)};exports.innerHeight=function(node){var height=node.clientHeight;node=node.ownerDocument.defaultView.getComputedStyle(node);height-=(0,_shims.int)(node.paddingTop);return height-=(0,_shims.int)(node.paddingBottom)};
exports.innerWidth=function(node){var width=node.clientWidth;node=node.ownerDocument.defaultView.getComputedStyle(node);width-=(0,_shims.int)(node.paddingLeft);return width-=(0,_shims.int)(node.paddingRight)};exports.offsetXYFromParent=function(evt,offsetParent,scale){var offsetParentRect=offsetParent===offsetParent.ownerDocument.body?{left:0,top:0}:offsetParent.getBoundingClientRect();return{x:(evt.clientX+offsetParent.scrollLeft-offsetParentRect.left)/scale,y:(evt.clientY+offsetParent.scrollTop-
offsetParentRect.top)/scale}};exports.createCSSTransform=function(controlPos,positionOffset){controlPos=getTranslation(controlPos,positionOffset,"px");return _defineProperty({},(0,_getPrefix.browserPrefixToKey)("transform",_getPrefix.default),controlPos)};exports.createSVGTransform=function(controlPos,positionOffset){return getTranslation(controlPos,positionOffset,"")};exports.getTranslation=getTranslation;exports.getTouch=function(e,identifier){return e.targetTouches&&(0,_shims.findInArray)(e.targetTouches,
function(t){return identifier===t.identifier})||e.changedTouches&&(0,_shims.findInArray)(e.changedTouches,function(t){return identifier===t.identifier})};exports.getTouchIdentifier=function(e){if(e.targetTouches&&e.targetTouches[0])return e.targetTouches[0].identifier;if(e.changedTouches&&e.changedTouches[0])return e.changedTouches[0].identifier};exports.addUserSelectStyles=function(doc){if(doc){var styleEl=doc.getElementById("react-draggable-style-el");styleEl||(styleEl=doc.createElement("style"),
styleEl.type="text/css",styleEl.id="react-draggable-style-el",styleEl.innerHTML=".react-draggable-transparent-selection *::-moz-selection {all: inherit;}\n",styleEl.innerHTML+=".react-draggable-transparent-selection *::selection {all: inherit;}\n",doc.getElementsByTagName("head")[0].appendChild(styleEl));doc.body&&addClassName(doc.body,"react-draggable-transparent-selection")}};exports.removeUserSelectStyles=function(doc){if(doc)try{if(doc.body&&removeClassName(doc.body,"react-draggable-transparent-selection"),
doc.selection)doc.selection.empty();else{var selection=(doc.defaultView||window).getSelection();selection&&"Caret"!==selection.type&&selection.removeAllRanges()}}catch(e){}};exports.addClassName=addClassName;exports.removeClassName=removeClassName;var _shims=require("module$node_modules$react_draggable$build$cjs$utils$shims"),_getPrefix=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{default:obj};var cache=_getRequireWildcardCache();
if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj.default=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react_draggable$build$cjs$utils$getPrefix")),
matchesSelectorFunc=""}
//# sourceMappingURL=module$node_modules$react_draggable$build$cjs$utils$domFns.js.map
